@@ -20,6 +20,14 @@ profile = utils.modified_lorentzian(time, baseline, slope, t0, DeltaP, Gamma) +\
     normal(scale=slope/20., size=len(time))
 mt = met.PressureTimeseries(time, profile)
 
+# Create temperature time-series
+DeltaT = -10. #K
+temp_profile = utils.modified_lorentzian(time, baseline, slope, t0, DeltaT,
+        Gamma) + normal(scale=slope/20., size=len(time))
+tt = met.TemperatureTimeseries(time, temp_profile, 
+        pressure_vortex_popts = [right_answer],
+        pressure_vortex_uncs = [np.array([0, 0, 0, 0, 0])])
+
 # Detrend
 window_size = Gamma
 detrended_data = mt.detrend_timeseries_boxcar(window_size)
@@ -60,7 +68,7 @@ def test_fit_vortex():
     old_popt, old_unc = utils.fit_vortex(vortices[0], [0., 1., 0., 1., 0.01], 
                           [[-1, -1, np.min(vortices[0]["time"]), 0, 0],
                            [1, 1, np.max(vortices[0]["time"]), 2, 1]],
-                          sigma=vortices[0]["pressure_scatter"])
+                          sigma=vortices[0]["scatter"])
 
     # Make sure best-fit parameters all match the right answers 
     assert(np.max(np.abs(old_popt - right_answer)/old_unc) < num_sigma)
@@ -84,3 +92,9 @@ def test_fit_all_vortices():
 
     # Make sure best-fit parameters all match the right answers
     assert(np.max(np.abs(popts[0] - right_answer)/uncs[0]) < num_sigma)
+
+def test_retrieve_vortices():
+    tt.retrieve_vortices()
+
+    # Make sure it retrieves the right number of data points
+    assert(len(tt.vortices[0]["time"]) == 30)
